@@ -5,11 +5,12 @@ from .results import Success, Failure
 class StringToDateParser():
     def parse_from(self, date_string, success_attribute='date'):
         if not date_string:
-            return Failure(message='date is missing')
+            return Failure(message=f'{success_attribute} is missing')
         try:
             return Success(**{success_attribute: date.fromisoformat(date_string)})
         except ValueError as e:
-            return Failure(message=str(e))
+            return Failure(message=f'{success_attribute}: {e}')
+
 
 class StringToIntParser:
     def parse_from(self, int_string, success_attribute='int_val'):
@@ -18,7 +19,6 @@ class StringToIntParser:
         except ValueError as e:
             return Failure(message="'{}' is not a valid integer".format(int_string))
 
+
 date_from_iso = StringToDateParser()
-
 int_from_string = StringToIntParser()
-
