@@ -1,5 +1,5 @@
-from dataclasses import dataclass, replace
-from re import I
+from dataclasses import dataclass
+
 
 @dataclass(init=False)
 class Result:
@@ -12,7 +12,8 @@ class Result:
         return self.body.get(name)
     
     def with_attributes(self, **kwargs):
-        return replace(self, **kwargs)
+        return self.__class__(**{**self.body, **kwargs})
+
 
 class Success(Result):
     def is_success(self):
@@ -34,6 +35,7 @@ class Success(Result):
     def or_fail_with(self, **kwargs):
         return self
 
+
 class Failure(Result):
     def is_success(self):
         return False
@@ -53,6 +55,7 @@ class Failure(Result):
     def or_fail_with(self, **kwargs):
         return Failure(**dict(reason=self), **kwargs)
 
+
 class PartialSuccess(Result):
     def is_success(self):
         return False
@@ -68,4 +71,4 @@ class PartialSuccess(Result):
         return self
 
     def or_fail_with(self, **kwargs):
-        return self
\ No newline at end of file
+        return self
